@@ -99,6 +99,7 @@ EXTENSIONS = {
     'js': {'text', 'javascript'},
     'json': {'text', 'json'},
     'jsonnet': {'text', 'jsonnet'},
+    'json5': {'text', 'json5'},
     'jsx': {'text', 'jsx'},
     'key': {'text', 'pem'},
     'kml': {'text', 'kml', 'xml'},
@@ -113,7 +114,7 @@ EXTENSIONS = {
     'liquid': {'text', 'liquid'},
     'lr': {'text', 'lektor'},
     'lua': {'text', 'lua'},
-    'm': {'text', 'c', 'objective-c'},
+    'm': {'text', 'objective-c'},
     'manifest': {'text', 'manifest'},
     'map': {'text', 'map'},
     'markdown': {'text', 'markdown'},
@@ -126,6 +127,8 @@ EXTENSIONS = {
     'mli': {'text', 'ocaml'},
     'mm': {'text', 'c++', 'objective-c++'},
     'modulemap': {'text', 'modulemap'},
+    'mscx': {'text', 'xml', 'musescore'},
+    'mscz': {'binary', 'zip', 'musescore'},
     'myst': {'text', 'myst'},
     'ngdoc': {'text', 'ngdoc'},
     'nim': {'text', 'nim'},
@@ -162,6 +165,7 @@ EXTENSIONS = {
     'pyx': {'text', 'cython'},
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
+    'qml': {'text', 'qml'},
     'r': {'text', 'r'},
     'rake': {'text', 'ruby'},
     'rb': {'text', 'ruby'},
@@ -312,6 +316,7 @@ NAMES = {
     'Pipfile': EXTENSIONS['toml'],
     'Pipfile.lock': EXTENSIONS['json'],
     'PKGBUILD': {'text', 'bash', 'pkgbuild', 'alpm'},
+    'poetry.lock': EXTENSIONS['toml'],
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
